Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(366)

Unified Diff: chrome/browser/nacl_host/pnacl_translation_cache.h

Issue 18640005: Rename PNaClTranslationCache->PnaclTranslationCache to match convention elsewhere (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/nacl_host/pnacl_translation_cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/nacl_host/pnacl_translation_cache.h
diff --git a/chrome/browser/nacl_host/pnacl_translation_cache.h b/chrome/browser/nacl_host/pnacl_translation_cache.h
index 14b18165d803a0cf332bc49bed4a432ea91f1181..6af0ddca94e4135bad6842c803cafb039003fea5 100644
--- a/chrome/browser/nacl_host/pnacl_translation_cache.h
+++ b/chrome/browser/nacl_host/pnacl_translation_cache.h
@@ -22,14 +22,14 @@ class Backend;
namespace pnacl_cache {
typedef base::Callback<void(int)> CompletionCallback;
-class PNaClTranslationCacheEntry;
+class PnaclTranslationCacheEntry;
extern const int kMaxMemCacheSize;
-class PNaClTranslationCache
- : public base::SupportsWeakPtr<PNaClTranslationCache> {
+class PnaclTranslationCache
+ : public base::SupportsWeakPtr<PnaclTranslationCache> {
public:
- PNaClTranslationCache();
- virtual ~PNaClTranslationCache();
+ PnaclTranslationCache();
+ virtual ~PnaclTranslationCache();
// Initialize the translation cache in |cache_dir| (or in memory if
// |in_memory| is true). Call |callback| with a 0 argument on sucess and
@@ -58,10 +58,10 @@ class PNaClTranslationCache
int Size();
private:
- friend class PNaClTranslationCacheEntry;
- // PNaClTranslationCacheEntry should only use the
- // OpComplete and backend methods on PNaClTranslationCache.
- void OpComplete(PNaClTranslationCacheEntry* entry);
+ friend class PnaclTranslationCacheEntry;
+ // PnaclTranslationCacheEntry should only use the
+ // OpComplete and backend methods on PnaclTranslationCache.
+ void OpComplete(PnaclTranslationCacheEntry* entry);
disk_cache::Backend* backend() { return disk_cache_; }
int InitWithDiskBackend(const base::FilePath& disk_cache_dir,
@@ -80,9 +80,9 @@ class PNaClTranslationCache
disk_cache::Backend* disk_cache_;
CompletionCallback init_callback_;
bool in_memory_;
- std::map<void*, scoped_refptr<PNaClTranslationCacheEntry> > open_entries_;
+ std::map<void*, scoped_refptr<PnaclTranslationCacheEntry> > open_entries_;
- DISALLOW_COPY_AND_ASSIGN(PNaClTranslationCache);
+ DISALLOW_COPY_AND_ASSIGN(PnaclTranslationCache);
};
} // namespace pnacl_cache
« no previous file with comments | « no previous file | chrome/browser/nacl_host/pnacl_translation_cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698